/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qgraphicswebview.sip"
#include <qgraphicswebview.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 199 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 88 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 1031 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsettings.sip"
#include <qwebsettings.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicswidget.sip"
#include <qgraphicswidget.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 115 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicslayout.sip"
#include <qgraphicslayout.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 176 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 179 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 182 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 191 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 194 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 197 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 200 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 203 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 206 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 209 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 212 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 215 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicstransform.sip"
#include <qgraphicstransform.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 607 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 329 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 245 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 248 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 578 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 251 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsscene.sip"
#include <qgraphicsscene.h>
#line 254 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicslayoutitem.sip"
#include <qgraphicslayoutitem.h>
#line 257 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 260 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQGraphicsWebView.cpp"


class sipQGraphicsWebView : public ::QGraphicsWebView
{
public:
    sipQGraphicsWebView(::QGraphicsItem*);
    virtual ~sipQGraphicsWebView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void advance(int) SIP_OVERRIDE;
    ::QRectF boundingRect() const SIP_OVERRIDE;
    ::QPainterPath shape() const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    bool collidesWithItem(const ::QGraphicsItem*, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool collidesWithPath(const ::QPainterPath&, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool isObscuredBy(const ::QGraphicsItem*) const SIP_OVERRIDE;
    ::QPainterPath opaqueArea() const SIP_OVERRIDE;
    void paint(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    int type() const SIP_OVERRIDE;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dropEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange, const ::QVariant&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    bool sceneEvent(::QEvent*) SIP_OVERRIDE;
    bool sceneEventFilter(::QGraphicsItem*, ::QEvent*) SIP_OVERRIDE;
    void wheelEvent(::QGraphicsSceneWheelEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    ::QSizeF sizeHint(::Qt::SizeHint, const ::QSizeF&) const SIP_OVERRIDE;
    void updateGeometry() SIP_OVERRIDE;
    void getContentsMargins(::qreal*, ::qreal*, ::qreal*, ::qreal*) const SIP_OVERRIDE;
    void setGeometry(const ::QRectF&) SIP_OVERRIDE;
    void paintWindowFrame(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    void initStyleOption(::QStyleOption*) const SIP_OVERRIDE;
    bool windowFrameEvent(::QEvent*) SIP_OVERRIDE;
    ::Qt::WindowFrameSection windowFrameSectionAt(const ::QPointF&) const SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void moveEvent(::QGraphicsSceneMoveEvent*) SIP_OVERRIDE;
    void polishEvent() SIP_OVERRIDE;
    void resizeEvent(::QGraphicsSceneResizeEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void grabMouseEvent(::QEvent*) SIP_OVERRIDE;
    void ungrabMouseEvent(::QEvent*) SIP_OVERRIDE;
    void grabKeyboardEvent(::QEvent*) SIP_OVERRIDE;
    void ungrabKeyboardEvent(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsWebView(const sipQGraphicsWebView &);
    sipQGraphicsWebView &operator = (const sipQGraphicsWebView &);

    char sipPyMethods[59];
};

sipQGraphicsWebView::sipQGraphicsWebView(::QGraphicsItem*a0): ::QGraphicsWebView(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsWebView::~sipQGraphicsWebView()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsWebView::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebKitWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsWebView);

    return ::QGraphicsWebView::metaObject();
}

int sipQGraphicsWebView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsWebView::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebKitWidgets_qt_metacall(sipPySelf, sipType_QGraphicsWebView, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsWebView::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebKitWidgets_qt_metacast(sipPySelf, sipType_QGraphicsWebView, _clname, &sipCpp) ? sipCpp : ::QGraphicsWebView::qt_metacast(_clname));
}

void sipQGraphicsWebView::advance(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_advance);

    if (!sipMeth)
    {
        ::QGraphicsWebView::advance(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWebKitWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRectF sipQGraphicsWebView::boundingRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRect);

    if (!sipMeth)
        return ::QGraphicsWebView::boundingRect();

    extern ::QRectF sipVH_QtWebKitWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPainterPath sipQGraphicsWebView::shape() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_shape);

    if (!sipMeth)
        return ::QGraphicsWebView::shape();

    extern ::QPainterPath sipVH_QtWebKitWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGraphicsWebView::contains(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_contains);

    if (!sipMeth)
        return ::QGraphicsWebView::contains(a0);

    extern bool sipVH_QtWebKitWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtWebKitWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::collidesWithItem(const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithItem);

    if (!sipMeth)
        return ::QGraphicsWebView::collidesWithItem(a0, a1);

    extern bool sipVH_QtWebKitWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*, ::Qt::ItemSelectionMode);

    return sipVH_QtWebKitWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsWebView::collidesWithPath(const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithPath);

    if (!sipMeth)
        return ::QGraphicsWebView::collidesWithPath(a0, a1);

    extern bool sipVH_QtWebKitWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPainterPath&, ::Qt::ItemSelectionMode);

    return sipVH_QtWebKitWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsWebView::isObscuredBy(const ::QGraphicsItem*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isObscuredBy);

    if (!sipMeth)
        return ::QGraphicsWebView::isObscuredBy(a0);

    extern bool sipVH_QtWebKitWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*);

    return sipVH_QtWebKitWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainterPath sipQGraphicsWebView::opaqueArea() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_opaqueArea);

    if (!sipMeth)
        return ::QGraphicsWebView::opaqueArea();

    extern ::QPainterPath sipVH_QtWebKitWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsWebView::paint(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_paint);

    if (!sipMeth)
    {
        ::QGraphicsWebView::paint(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWebKitWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtWebKitWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQGraphicsWebView::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QGraphicsWebView::type();

    extern int sipVH_QtWebKitWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsWebView::contextMenuEvent(::QGraphicsSceneContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneContextMenuEvent*);

    sipVH_QtWebKitWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::dragEnterEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWebKitWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::dragLeaveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWebKitWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::dragMoveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWebKitWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::dropEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtWebKitWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWebKitWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWebKitWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::hoverEnterEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_hoverEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::hoverEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtWebKitWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::hoverLeaveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_hoverLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::hoverLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtWebKitWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::hoverMoveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_hoverMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::hoverMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtWebKitWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWebKitWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQGraphicsWebView::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QGraphicsWebView::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWebKitWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWebKitWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQGraphicsWebView::itemChange(::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_itemChange);

    if (!sipMeth)
        return ::QGraphicsWebView::itemChange(a0, a1);

    extern ::QVariant sipVH_QtWebKitWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem::GraphicsItemChange, const ::QVariant&);

    return sipVH_QtWebKitWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsWebView::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWebKitWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWebKitWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWebKitWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::mouseMoveEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWebKitWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::mousePressEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWebKitWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::mouseReleaseEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtWebKitWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::sceneEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_sceneEvent);

    if (!sipMeth)
        return ::QGraphicsWebView::sceneEvent(a0);

    extern bool sipVH_QtWebKitWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKitWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::sceneEventFilter(::QGraphicsItem*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_sceneEventFilter);

    if (!sipMeth)
        return ::QGraphicsWebView::sceneEventFilter(a0, a1);

    extern bool sipVH_QtWebKitWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem*, ::QEvent*);

    return sipVH_QtWebKitWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsWebView::wheelEvent(::QGraphicsSceneWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneWheelEvent*);

    sipVH_QtWebKitWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsWebView::event(a0);

    extern bool sipVH_QtWebKitWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKitWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsWebView::eventFilter(a0, a1);

    extern bool sipVH_QtWebKitWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebKitWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsWebView::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebKitWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebKitWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsWebView::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKitWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsWebView::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKitWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSizeF sipQGraphicsWebView::sizeHint(::Qt::SizeHint a0, const ::QSizeF& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[39]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QGraphicsWebView::sizeHint(a0, a1);

    extern ::QSizeF sipVH_QtWebKitWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::SizeHint, const ::QSizeF&);

    return sipVH_QtWebKitWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGraphicsWebView::updateGeometry()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_updateGeometry);

    if (!sipMeth)
    {
        ::QGraphicsWebView::updateGeometry();
        return;
    }

    extern void sipVH_QtWebKitWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWebKitWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsWebView::getContentsMargins(::qreal*a0, ::qreal*a1, ::qreal*a2, ::qreal*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_getContentsMargins);

    if (!sipMeth)
    {
        ::QGraphicsWebView::getContentsMargins(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtWebKitWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal*, ::qreal*, ::qreal*, ::qreal*);

    sipVH_QtWebKitWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQGraphicsWebView::setGeometry(const ::QRectF& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_setGeometry);

    if (!sipMeth)
    {
        ::QGraphicsWebView::setGeometry(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRectF&);

    sipVH_QtWebKitWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::paintWindowFrame(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_paintWindowFrame);

    if (!sipMeth)
    {
        ::QGraphicsWebView::paintWindowFrame(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWebKitWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtWebKitWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQGraphicsWebView::initStyleOption(::QStyleOption*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QGraphicsWebView::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOption*);

    sipVH_QtWebKitWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::windowFrameEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_windowFrameEvent);

    if (!sipMeth)
        return ::QGraphicsWebView::windowFrameEvent(a0);

    extern bool sipVH_QtWebKitWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKitWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt::WindowFrameSection sipQGraphicsWebView::windowFrameSectionAt(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_windowFrameSectionAt);

    if (!sipMeth)
        return ::QGraphicsWebView::windowFrameSectionAt(a0);

    extern ::Qt::WindowFrameSection sipVH_QtWebKitWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtWebKitWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWebKitWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsWebView::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QGraphicsWebView::focusNextPrevChild(a0);

    extern bool sipVH_QtWebKitWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWebKitWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWebKitWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::moveEvent(::QGraphicsSceneMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMoveEvent*);

    sipVH_QtWebKitWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::polishEvent()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_polishEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::polishEvent();
        return;
    }

    extern void sipVH_QtWebKitWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWebKitWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsWebView::resizeEvent(::QGraphicsSceneResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[53], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneResizeEvent*);

    sipVH_QtWebKitWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::showEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWebKitWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::grabMouseEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_grabMouseEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::grabMouseEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::ungrabMouseEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[56], &sipPySelf, SIP_NULLPTR, sipName_ungrabMouseEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::ungrabMouseEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::grabKeyboardEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[57], &sipPySelf, SIP_NULLPTR, sipName_grabKeyboardEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::grabKeyboardEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsWebView::ungrabKeyboardEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[58], &sipPySelf, SIP_NULLPTR, sipName_ungrabKeyboardEvent);

    if (!sipMeth)
    {
        ::QGraphicsWebView::ungrabKeyboardEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsWebView_page, "page(self) -> Optional[QWebPage]");

extern "C" {static PyObject *meth_QGraphicsWebView_page(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_page(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QWebPage*sipRes;

            sipRes = sipCpp->page();

            return sipConvertFromType(sipRes, sipType_QWebPage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_page, doc_QGraphicsWebView_page);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setPage, "setPage(self, a0: Optional[QWebPage])");

extern "C" {static PyObject *meth_QGraphicsWebView_setPage(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage* a0;
        PyObject *a0Keep;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, &a0Keep, sipType_QWebPage, &a0))
        {
            sipCpp->setPage(a0);

            sipKeepReference(sipSelf, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setPage, doc_QGraphicsWebView_setPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QGraphicsWebView_url(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_url, doc_QGraphicsWebView_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setUrl, "setUrl(self, a0: QUrl)");

extern "C" {static PyObject *meth_QGraphicsWebView_setUrl(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setUrl, doc_QGraphicsWebView_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_title, "title(self) -> str");

extern "C" {static PyObject *meth_QGraphicsWebView_title(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_title, doc_QGraphicsWebView_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_icon, "icon(self) -> QIcon");

extern "C" {static PyObject *meth_QGraphicsWebView_icon(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_icon, doc_QGraphicsWebView_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_zoomFactor, "zoomFactor(self) -> float");

extern "C" {static PyObject *meth_QGraphicsWebView_zoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_zoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->zoomFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_zoomFactor, doc_QGraphicsWebView_zoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setZoomFactor, "setZoomFactor(self, a0: float)");

extern "C" {static PyObject *meth_QGraphicsWebView_setZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsWebView, &sipCpp, &a0))
        {
            sipCpp->setZoomFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setZoomFactor, doc_QGraphicsWebView_setZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_isModified, "isModified(self) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_isModified(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_isModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isModified();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_isModified, doc_QGraphicsWebView_isModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_load, "load(self, url: QUrl)\n"
"load(self, request: QNetworkRequest, operation: QNetworkAccessManager.Operation = QNetworkAccessManager.GetOperation, body: Union[QByteArray, bytes, bytearray] = QByteArray())");

extern "C" {static PyObject *meth_QGraphicsWebView_load(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_load(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QUrl, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QNetworkAccessManager::Operation a1 = QNetworkAccessManager::GetOperation;
        const ::QByteArray& a2def = QByteArray();
        const ::QByteArray* a2 = &a2def;
        int a2State = 0;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_operation,
            sipName_body,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EJ1", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QNetworkAccessManager_Operation, &a1, sipType_QByteArray, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0, a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QByteArray *>(a2), sipType_QByteArray, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_load, doc_QGraphicsWebView_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setHtml, "setHtml(self, html: Optional[str], baseUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QGraphicsWebView_setHtml(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setHtml(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_baseUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J9", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QString, &a0, &a0State, sipType_QUrl, &a1))
        {
            sipCpp->setHtml(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setHtml, doc_QGraphicsWebView_setHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setContent, "setContent(self, data: Union[QByteArray, bytes, bytearray], mimeType: Optional[str] = '', baseUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QGraphicsWebView_setContent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setContent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QUrl& a2def = QUrl();
        const ::QUrl* a2 = &a2def;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mimeType,
            sipName_baseUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J9", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QUrl, &a2))
        {
            sipCpp->setContent(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setContent, doc_QGraphicsWebView_setContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_history, "history(self) -> Optional[QWebHistory]");

extern "C" {static PyObject *meth_QGraphicsWebView_history(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_history(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QWebHistory*sipRes;

            sipRes = sipCpp->history();

            return sipConvertFromType(sipRes, sipType_QWebHistory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_history, doc_QGraphicsWebView_history);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_settings, "settings(self) -> Optional[QWebSettings]");

extern "C" {static PyObject *meth_QGraphicsWebView_settings(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_settings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QWebSettings*sipRes;

            sipRes = sipCpp->settings();

            return sipConvertFromType(sipRes, sipType_QWebSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_settings, doc_QGraphicsWebView_settings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_pageAction, "pageAction(self, action: QWebPage.WebAction) -> Optional[QAction]");

extern "C" {static PyObject *meth_QGraphicsWebView_pageAction(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_pageAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::WebAction a0;
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QWebPage_WebAction, &a0))
        {
            ::QAction*sipRes;

            sipRes = sipCpp->pageAction(a0);

            return sipConvertFromType(sipRes, sipType_QAction, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_pageAction, doc_QGraphicsWebView_pageAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_triggerPageAction, "triggerPageAction(self, action: QWebPage.WebAction, checked: bool = False)");

extern "C" {static PyObject *meth_QGraphicsWebView_triggerPageAction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_triggerPageAction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::WebAction a0;
        bool a1 = 0;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_checked,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QWebPage_WebAction, &a0, &a1))
        {
            sipCpp->triggerPageAction(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_triggerPageAction, doc_QGraphicsWebView_triggerPageAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_findText, "findText(self, subString: Optional[str], options: QWebPage.FindFlags = 0) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_findText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_findText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebPage::FindFlags a1def = 0;
        ::QWebPage::FindFlags* a1 = &a1def;
        int a1State = 0;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QString, &a0, &a0State, sipType_QWebPage_FindFlags, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->findText(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_QWebPage_FindFlags, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_findText, doc_QGraphicsWebView_findText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setGeometry, "setGeometry(self, rect: QRectF)");

extern "C" {static PyObject *meth_QGraphicsWebView_setGeometry(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRectF* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QRectF, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::setGeometry(*a0) : sipCpp->setGeometry(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setGeometry, doc_QGraphicsWebView_setGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_updateGeometry, "updateGeometry(self)");

extern "C" {static PyObject *meth_QGraphicsWebView_updateGeometry(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_updateGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::updateGeometry() : sipCpp->updateGeometry());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_updateGeometry, doc_QGraphicsWebView_updateGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_paint, "paint(self, painter: Optional[QPainter], option: Optional[QStyleOptionGraphicsItem], widget: Optional[QWidget] = None)");

extern "C" {static PyObject *meth_QGraphicsWebView_paint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_paint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QStyleOptionGraphicsItem* a1;
        ::QWidget* a2 = 0;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J8|J8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QPainter, &a0, sipType_QStyleOptionGraphicsItem, &a1, sipType_QWidget, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::paint(a0, a1, a2) : sipCpp->paint(a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_paint, doc_QGraphicsWebView_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_itemChange, "itemChange(self, change: QGraphicsItem.GraphicsItemChange, value: Any) -> Any");

extern "C" {static PyObject *meth_QGraphicsWebView_itemChange(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_itemChange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsItem::GraphicsItemChange a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsItem_GraphicsItemChange, &a0, sipType_QVariant, &a1, &a1State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGraphicsWebView::itemChange(a0, *a1) : sipCpp->itemChange(a0, *a1)));
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_itemChange, doc_QGraphicsWebView_itemChange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_event, "event(self, a0: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_event(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsWebView::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_event, doc_QGraphicsWebView_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_sizeHint, "sizeHint(self, which: Qt.SizeHint, constraint: QSizeF) -> QSizeF");

extern "C" {static PyObject *meth_QGraphicsWebView_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::SizeHint a0;
        const ::QSizeF* a1;
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_Qt_SizeHint, &a0, sipType_QSizeF, &a1))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF((sipSelfWasArg ? sipCpp->::QGraphicsWebView::sizeHint(a0, *a1) : sipCpp->sizeHint(a0, *a1)));

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_sizeHint, doc_QGraphicsWebView_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_inputMethodQuery, "inputMethodQuery(self, query: Qt.InputMethodQuery) -> Any");

extern "C" {static PyObject *meth_QGraphicsWebView_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::InputMethodQuery a0;
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGraphicsWebView::inputMethodQuery(a0) : sipCpp->inputMethodQuery(a0)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_inputMethodQuery, doc_QGraphicsWebView_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_stop, "stop(self)");

extern "C" {static PyObject *meth_QGraphicsWebView_stop(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_stop, doc_QGraphicsWebView_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_back, "back(self)");

extern "C" {static PyObject *meth_QGraphicsWebView_back(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_back(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            sipCpp->back();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_back, doc_QGraphicsWebView_back);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_forward, "forward(self)");

extern "C" {static PyObject *meth_QGraphicsWebView_forward(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_forward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            sipCpp->forward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_forward, doc_QGraphicsWebView_forward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_reload, "reload(self)");

extern "C" {static PyObject *meth_QGraphicsWebView_reload(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_reload(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            sipCpp->reload();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_reload, doc_QGraphicsWebView_reload);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_mousePressEvent, "mousePressEvent(self, a0: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_mousePressEvent, doc_QGraphicsWebView_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, a0: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_mouseDoubleClickEvent, doc_QGraphicsWebView_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_mouseReleaseEvent, "mouseReleaseEvent(self, a0: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_mouseReleaseEvent, doc_QGraphicsWebView_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_mouseMoveEvent, "mouseMoveEvent(self, a0: Optional[QGraphicsSceneMouseEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneMouseEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_mouseMoveEvent, doc_QGraphicsWebView_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_hoverMoveEvent, "hoverMoveEvent(self, a0: Optional[QGraphicsSceneHoverEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_hoverMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_hoverMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneHoverEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneHoverEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::hoverMoveEvent(a0) : sipCpp->hoverMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_hoverMoveEvent, doc_QGraphicsWebView_hoverMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_hoverLeaveEvent, "hoverLeaveEvent(self, a0: Optional[QGraphicsSceneHoverEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_hoverLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_hoverLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneHoverEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneHoverEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::hoverLeaveEvent(a0) : sipCpp->hoverLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_hoverLeaveEvent, doc_QGraphicsWebView_hoverLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_wheelEvent, "wheelEvent(self, a0: Optional[QGraphicsSceneWheelEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneWheelEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_wheelEvent, doc_QGraphicsWebView_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_keyPressEvent, "keyPressEvent(self, a0: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_keyPressEvent, doc_QGraphicsWebView_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_keyReleaseEvent, "keyReleaseEvent(self, a0: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_keyReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_keyReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::keyReleaseEvent(a0) : sipCpp->keyReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_keyReleaseEvent, doc_QGraphicsWebView_keyReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_contextMenuEvent, "contextMenuEvent(self, a0: Optional[QGraphicsSceneContextMenuEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneContextMenuEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_contextMenuEvent, doc_QGraphicsWebView_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_dragEnterEvent, "dragEnterEvent(self, a0: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_dragEnterEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_dragEnterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::dragEnterEvent(a0) : sipCpp->dragEnterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_dragEnterEvent, doc_QGraphicsWebView_dragEnterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_dragLeaveEvent, "dragLeaveEvent(self, a0: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_dragLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_dragLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::dragLeaveEvent(a0) : sipCpp->dragLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_dragLeaveEvent, doc_QGraphicsWebView_dragLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_dragMoveEvent, "dragMoveEvent(self, a0: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_dragMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_dragMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::dragMoveEvent(a0) : sipCpp->dragMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_dragMoveEvent, doc_QGraphicsWebView_dragMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_dropEvent, "dropEvent(self, a0: Optional[QGraphicsSceneDragDropEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsSceneDragDropEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QGraphicsSceneDragDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_dropEvent, doc_QGraphicsWebView_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_focusInEvent, "focusInEvent(self, a0: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_focusInEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::focusInEvent(a0) : sipCpp->focusInEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_focusInEvent, doc_QGraphicsWebView_focusInEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_focusOutEvent, "focusOutEvent(self, a0: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_focusOutEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_focusOutEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::focusOutEvent(a0) : sipCpp->focusOutEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_focusOutEvent, doc_QGraphicsWebView_focusOutEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_inputMethodEvent, "inputMethodEvent(self, a0: Optional[QInputMethodEvent])");

extern "C" {static PyObject *meth_QGraphicsWebView_inputMethodEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_inputMethodEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QInputMethodEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QInputMethodEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsWebView::inputMethodEvent(a0) : sipCpp->inputMethodEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_inputMethodEvent, doc_QGraphicsWebView_inputMethodEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_focusNextPrevChild, "focusNextPrevChild(self, next: bool) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_focusNextPrevChild(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_focusNextPrevChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QGraphicsWebView, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsWebView::focusNextPrevChild(a0) : sipCpp->focusNextPrevChild(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_focusNextPrevChild, doc_QGraphicsWebView_focusNextPrevChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_sceneEvent, "sceneEvent(self, a0: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_sceneEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_sceneEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsWebView::sceneEvent(a0) : sipCpp->sceneEvent(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_sceneEvent, doc_QGraphicsWebView_sceneEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_resizesToContents, "resizesToContents(self) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_resizesToContents(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_resizesToContents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->resizesToContents();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_resizesToContents, doc_QGraphicsWebView_resizesToContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setResizesToContents, "setResizesToContents(self, enabled: bool)");

extern "C" {static PyObject *meth_QGraphicsWebView_setResizesToContents(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setResizesToContents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QGraphicsWebView, &sipCpp, &a0))
        {
            sipCpp->setResizesToContents(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setResizesToContents, doc_QGraphicsWebView_setResizesToContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_isTiledBackingStoreFrozen, "isTiledBackingStoreFrozen(self) -> bool");

extern "C" {static PyObject *meth_QGraphicsWebView_isTiledBackingStoreFrozen(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_isTiledBackingStoreFrozen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isTiledBackingStoreFrozen();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_isTiledBackingStoreFrozen, doc_QGraphicsWebView_isTiledBackingStoreFrozen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setTiledBackingStoreFrozen, "setTiledBackingStoreFrozen(self, frozen: bool)");

extern "C" {static PyObject *meth_QGraphicsWebView_setTiledBackingStoreFrozen(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setTiledBackingStoreFrozen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QGraphicsWebView, &sipCpp, &a0))
        {
            sipCpp->setTiledBackingStoreFrozen(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setTiledBackingStoreFrozen, doc_QGraphicsWebView_setTiledBackingStoreFrozen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_renderHints, "renderHints(self) -> QPainter.RenderHints");

extern "C" {static PyObject *meth_QGraphicsWebView_renderHints(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_renderHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsWebView, &sipCpp))
        {
            ::QPainter::RenderHints*sipRes;

            sipRes = new ::QPainter::RenderHints(sipCpp->renderHints());

            return sipConvertFromNewType(sipRes, sipType_QPainter_RenderHints, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_renderHints, doc_QGraphicsWebView_renderHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setRenderHints, "setRenderHints(self, hints: QPainter.RenderHints)");

extern "C" {static PyObject *meth_QGraphicsWebView_setRenderHints(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setRenderHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::RenderHints* a0;
        int a0State = 0;
        ::QGraphicsWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QPainter_RenderHints, &a0, &a0State))
        {
            sipCpp->setRenderHints(*a0);
            sipReleaseType(a0, sipType_QPainter_RenderHints, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setRenderHints, doc_QGraphicsWebView_setRenderHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsWebView_setRenderHint, "setRenderHint(self, hint: QPainter.RenderHint, enabled: bool = True)");

extern "C" {static PyObject *meth_QGraphicsWebView_setRenderHint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsWebView_setRenderHint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::RenderHint a0;
        bool a1 = 1;
        ::QGraphicsWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QGraphicsWebView, &sipCpp, sipType_QPainter_RenderHint, &a0, &a1))
        {
            sipCpp->setRenderHint(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsWebView, sipName_setRenderHint, doc_QGraphicsWebView_setRenderHint);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsWebView(void *, const sipTypeDef *);}
static void *cast_QGraphicsWebView(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsWebView *sipCpp = reinterpret_cast< ::QGraphicsWebView *>(sipCppV);

    if (targetType == sipType_QGraphicsWebView)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsWidget)->ctd_cast(static_cast< ::QGraphicsWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsWebView(void *, int);}
static void release_QGraphicsWebView(void *sipCppV, int)
{
    ::QGraphicsWebView *sipCpp = reinterpret_cast< ::QGraphicsWebView *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsWebView(Py_ssize_t);}
static void *array_QGraphicsWebView(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsWebView[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsWebView(void *);}
static void array_delete_QGraphicsWebView(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsWebView *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsWebView(sipSimpleWrapper *);}
static void dealloc_QGraphicsWebView(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsWebView *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsWebView(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsWebView(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsWebView(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsWebView *sipCpp = SIP_NULLPTR;

    {
        ::QGraphicsItem* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QGraphicsItem, &a0, sipOwner))
        {
            sipCpp = new sipQGraphicsWebView(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsWebView[] = {{12, 3, 1}};


static PyMethodDef methods_QGraphicsWebView[] = {
    {sipName_back, meth_QGraphicsWebView_back, METH_VARARGS, doc_QGraphicsWebView_back},
    {sipName_contextMenuEvent, meth_QGraphicsWebView_contextMenuEvent, METH_VARARGS, doc_QGraphicsWebView_contextMenuEvent},
    {sipName_dragEnterEvent, meth_QGraphicsWebView_dragEnterEvent, METH_VARARGS, doc_QGraphicsWebView_dragEnterEvent},
    {sipName_dragLeaveEvent, meth_QGraphicsWebView_dragLeaveEvent, METH_VARARGS, doc_QGraphicsWebView_dragLeaveEvent},
    {sipName_dragMoveEvent, meth_QGraphicsWebView_dragMoveEvent, METH_VARARGS, doc_QGraphicsWebView_dragMoveEvent},
    {sipName_dropEvent, meth_QGraphicsWebView_dropEvent, METH_VARARGS, doc_QGraphicsWebView_dropEvent},
    {sipName_event, meth_QGraphicsWebView_event, METH_VARARGS, doc_QGraphicsWebView_event},
    {sipName_findText, SIP_MLMETH_CAST(meth_QGraphicsWebView_findText), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_findText},
    {sipName_focusInEvent, meth_QGraphicsWebView_focusInEvent, METH_VARARGS, doc_QGraphicsWebView_focusInEvent},
    {sipName_focusNextPrevChild, meth_QGraphicsWebView_focusNextPrevChild, METH_VARARGS, doc_QGraphicsWebView_focusNextPrevChild},
    {sipName_focusOutEvent, meth_QGraphicsWebView_focusOutEvent, METH_VARARGS, doc_QGraphicsWebView_focusOutEvent},
    {sipName_forward, meth_QGraphicsWebView_forward, METH_VARARGS, doc_QGraphicsWebView_forward},
    {sipName_history, meth_QGraphicsWebView_history, METH_VARARGS, doc_QGraphicsWebView_history},
    {sipName_hoverLeaveEvent, meth_QGraphicsWebView_hoverLeaveEvent, METH_VARARGS, doc_QGraphicsWebView_hoverLeaveEvent},
    {sipName_hoverMoveEvent, meth_QGraphicsWebView_hoverMoveEvent, METH_VARARGS, doc_QGraphicsWebView_hoverMoveEvent},
    {sipName_icon, meth_QGraphicsWebView_icon, METH_VARARGS, doc_QGraphicsWebView_icon},
    {sipName_inputMethodEvent, meth_QGraphicsWebView_inputMethodEvent, METH_VARARGS, doc_QGraphicsWebView_inputMethodEvent},
    {sipName_inputMethodQuery, meth_QGraphicsWebView_inputMethodQuery, METH_VARARGS, doc_QGraphicsWebView_inputMethodQuery},
    {sipName_isModified, meth_QGraphicsWebView_isModified, METH_VARARGS, doc_QGraphicsWebView_isModified},
    {sipName_isTiledBackingStoreFrozen, meth_QGraphicsWebView_isTiledBackingStoreFrozen, METH_VARARGS, doc_QGraphicsWebView_isTiledBackingStoreFrozen},
    {sipName_itemChange, meth_QGraphicsWebView_itemChange, METH_VARARGS, doc_QGraphicsWebView_itemChange},
    {sipName_keyPressEvent, meth_QGraphicsWebView_keyPressEvent, METH_VARARGS, doc_QGraphicsWebView_keyPressEvent},
    {sipName_keyReleaseEvent, meth_QGraphicsWebView_keyReleaseEvent, METH_VARARGS, doc_QGraphicsWebView_keyReleaseEvent},
    {sipName_load, SIP_MLMETH_CAST(meth_QGraphicsWebView_load), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_load},
    {sipName_mouseDoubleClickEvent, meth_QGraphicsWebView_mouseDoubleClickEvent, METH_VARARGS, doc_QGraphicsWebView_mouseDoubleClickEvent},
    {sipName_mouseMoveEvent, meth_QGraphicsWebView_mouseMoveEvent, METH_VARARGS, doc_QGraphicsWebView_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QGraphicsWebView_mousePressEvent, METH_VARARGS, doc_QGraphicsWebView_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QGraphicsWebView_mouseReleaseEvent, METH_VARARGS, doc_QGraphicsWebView_mouseReleaseEvent},
    {sipName_page, meth_QGraphicsWebView_page, METH_VARARGS, doc_QGraphicsWebView_page},
    {sipName_pageAction, meth_QGraphicsWebView_pageAction, METH_VARARGS, doc_QGraphicsWebView_pageAction},
    {sipName_paint, SIP_MLMETH_CAST(meth_QGraphicsWebView_paint), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_paint},
    {sipName_reload, meth_QGraphicsWebView_reload, METH_VARARGS, doc_QGraphicsWebView_reload},
    {sipName_renderHints, meth_QGraphicsWebView_renderHints, METH_VARARGS, doc_QGraphicsWebView_renderHints},
    {sipName_resizesToContents, meth_QGraphicsWebView_resizesToContents, METH_VARARGS, doc_QGraphicsWebView_resizesToContents},
    {sipName_sceneEvent, meth_QGraphicsWebView_sceneEvent, METH_VARARGS, doc_QGraphicsWebView_sceneEvent},
    {sipName_setContent, SIP_MLMETH_CAST(meth_QGraphicsWebView_setContent), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_setContent},
    {sipName_setGeometry, meth_QGraphicsWebView_setGeometry, METH_VARARGS, doc_QGraphicsWebView_setGeometry},
    {sipName_setHtml, SIP_MLMETH_CAST(meth_QGraphicsWebView_setHtml), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_setHtml},
    {sipName_setPage, meth_QGraphicsWebView_setPage, METH_VARARGS, doc_QGraphicsWebView_setPage},
    {sipName_setRenderHint, SIP_MLMETH_CAST(meth_QGraphicsWebView_setRenderHint), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_setRenderHint},
    {sipName_setRenderHints, meth_QGraphicsWebView_setRenderHints, METH_VARARGS, doc_QGraphicsWebView_setRenderHints},
    {sipName_setResizesToContents, meth_QGraphicsWebView_setResizesToContents, METH_VARARGS, doc_QGraphicsWebView_setResizesToContents},
    {sipName_setTiledBackingStoreFrozen, meth_QGraphicsWebView_setTiledBackingStoreFrozen, METH_VARARGS, doc_QGraphicsWebView_setTiledBackingStoreFrozen},
    {sipName_setUrl, meth_QGraphicsWebView_setUrl, METH_VARARGS, doc_QGraphicsWebView_setUrl},
    {sipName_setZoomFactor, meth_QGraphicsWebView_setZoomFactor, METH_VARARGS, doc_QGraphicsWebView_setZoomFactor},
    {sipName_settings, meth_QGraphicsWebView_settings, METH_VARARGS, doc_QGraphicsWebView_settings},
    {sipName_sizeHint, meth_QGraphicsWebView_sizeHint, METH_VARARGS, doc_QGraphicsWebView_sizeHint},
    {sipName_stop, meth_QGraphicsWebView_stop, METH_VARARGS, doc_QGraphicsWebView_stop},
    {sipName_title, meth_QGraphicsWebView_title, METH_VARARGS, doc_QGraphicsWebView_title},
    {sipName_triggerPageAction, SIP_MLMETH_CAST(meth_QGraphicsWebView_triggerPageAction), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsWebView_triggerPageAction},
    {sipName_updateGeometry, meth_QGraphicsWebView_updateGeometry, METH_VARARGS, doc_QGraphicsWebView_updateGeometry},
    {sipName_url, meth_QGraphicsWebView_url, METH_VARARGS, doc_QGraphicsWebView_url},
    {sipName_wheelEvent, meth_QGraphicsWebView_wheelEvent, METH_VARARGS, doc_QGraphicsWebView_wheelEvent},
    {sipName_zoomFactor, meth_QGraphicsWebView_zoomFactor, METH_VARARGS, doc_QGraphicsWebView_zoomFactor}
};

PyDoc_STRVAR(doc_QGraphicsWebView, "\1QGraphicsWebView(parent: Optional[QGraphicsItem] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGraphicsWebView[] = {
    {"linkClicked(QUrl)", "\1linkClicked(self, a0: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusBarMessage(QString)", "\1statusBarMessage(self, message: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"iconChanged()", "\1iconChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleChanged(QString)", "\1titleChanged(self, a0: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"urlChanged(QUrl)", "\1urlChanged(self, a0: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadProgress(int)", "\1loadProgress(self, progress: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadFinished(bool)", "\1loadFinished(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadStarted()", "\1loadStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGraphicsWebView = {
    &::QGraphicsWebView::staticMetaObject,
    0,
    signals_QGraphicsWebView,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QGraphicsWebView = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsWebView,
        SIP_NULLPTR,
        &plugin_QGraphicsWebView,
    },
    {
        sipNameNr_QGraphicsWebView,
        {0, 0, 1},
        54, methods_QGraphicsWebView,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsWebView,
    -1,
    -1,
    supers_QGraphicsWebView,
    SIP_NULLPTR,
    init_type_QGraphicsWebView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsWebView,
    SIP_NULLPTR,
    array_QGraphicsWebView,
    SIP_NULLPTR,
    release_QGraphicsWebView,
    cast_QGraphicsWebView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsWebView,
    sizeof (::QGraphicsWebView),
};
